<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
<context>
    <name>dcc::datetime::Language</name>
    <message>
        <source>Abkhazian</source>
        <translation>ཨ་པུའུ་ཧ་ཞི་ཡ་སྐད།</translation>
    </message>
    <message>
        <source>Achinese</source>
        <translation>ཡ་ཆི་སྐད།</translation>
    </message>
    <message>
        <source>Acoli</source>
        <translation>ཨ་ཆའོ་ལི་སྐད།</translation>
    </message>
    <message>
        <source>Adangme</source>
        <translation>ཨ་ཏང་མེ་སྐད།</translation>
    </message>
    <message>
        <source>Adyghe</source>
        <translation>ཨ་ཏི་ཀེ་སྐད།</translation>
    </message>
    <message>
        <source>Afar</source>
        <translation>ཨ་ཧྥེར་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Afrihili</source>
        <translation>ཨ་ཧྥུ་ལི་ཞི་ལི་སྐད།</translation>
    </message>
    <message>
        <source>Afrikaans</source>
        <translation>ཨ་ཧྥེ་རི་ཁ་ལྷོ་མའི་ཧོ་ལན་སྐད།</translation>
    </message>
    <message>
        <source>Aghem</source>
        <translation>ཡ་ཧན་སྐད།</translation>
    </message>
    <message>
        <source>Ainu</source>
        <translation>ཨ་དབྱི་ནུའུ་སྐད།</translation>
    </message>
    <message>
        <source>Akan</source>
        <translation>ཨ་ཁེན་སྐད།</translation>
    </message>
    <message>
        <source>Akkadian</source>
        <translation>ཨ་ཁེ་ཏེ་སྐད།</translation>
    </message>
    <message>
        <source>Akoose</source>
        <translation>ཨ་ཁུ་སེ་སྐད།</translation>
    </message>
    <message>
        <source>Albanian</source>
        <translation>ཨར་པ་ནི་ཡ་སྐད།</translation>
    </message>
    <message>
        <source>Aleut</source>
        <translation>ཨ་ལིའུ་ཧྲེན་སྐད།</translation>
    </message>
    <message>
        <source>Amharic</source>
        <translation>ཨ་མུའུ་ཧ་ལ་སྐད།</translation>
    </message>
    <message>
        <source>Ancient Egyptian</source>
        <translation>གནའ་བོའི་ཨེ་ཅིབ་ཀྱི་སྐད།</translation>
    </message>
    <message>
        <source>Ancient Greek</source>
        <translation>གནའ་བོའི་ཀེ་རི་སེའི་སྐད།</translation>
    </message>
    <message>
        <source>Angika</source>
        <translation>ཨང་ཅ་སྐད།</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>ཨ་རབ་ཀྱི་སྐད།</translation>
    </message>
    <message>
        <source>Modern Standard Arabic</source>
        <translation>དེང་རབས་ཀྱི་ཚད་ལྡན་ཨ་རབ་སྐད།</translation>
    </message>
    <message>
        <source>Aragonese</source>
        <translation>ཨ་ར་ཀུང་སྐད།</translation>
    </message>
    <message>
        <source>Aramaic</source>
        <translation>ཨ་ར་སྨི་སྐད།</translation>
    </message>
    <message>
        <source>Arapaho</source>
        <translation>ཨ་ར་ཕ་ཧོ་སྐད།</translation>
    </message>
    <message>
        <source>Arawak</source>
        <translation>ཨ་ར་ཝ་ཁེ་སྐད།</translation>
    </message>
    <message>
        <source>Armenian</source>
        <translation>ཡ་མེ་ནི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <source>Aromanian</source>
        <translation>ཨ་རོ་མ་ནི་ཡ་སྐད།</translation>
    </message>
    <message>
        <source>Assamese</source>
        <translation>ཨ་ས་མུའུ་སྐད།</translation>
    </message>
    <message>
        <source>Asturian</source>
        <translation>ཨ་སི་ཐུ་ལི་ཡ་སི་སྐད།</translation>
    </message>
    <message>
        <source>Asu</source>
        <translation>ཕ་ལེ་སྐད།</translation>
    </message>
    <message>
        <source>Atikamekw</source>
        <translation>ཨ་ཐི་ཁ་སྨི་ཁེ་སྐད།</translation>
    </message>
    <message>
        <source>Atsam</source>
        <translation>ཨ་ཚན་སྐད།</translation>
    </message>
    <message>
        <source>Avaric</source>
        <translation>ཨར་ཝ་སྐད།</translation>
    </message>
    <message>
        <source>Avestan</source>
        <translation>ཨ་ཝེ་སི་ཐ་སྐད།</translation>
    </message>
    <message>
        <source>Awadhi</source>
        <translation>ཨ་ཝ་ཏེ་སྐད།</translation>
    </message>
    <message>
        <source>Aymara</source>
        <translation>ཨེ་མ་ར་སྐད།</translation>
    </message>
    <message>
        <source>Azerbaijani</source>
        <translation>ཨ་སའེ་པའེ་ཅང་སྐད།</translation>
    </message>
    <message>
        <source>Azerbaijani (Arabic)</source>
        <translation>ལྷོ་ཨ་སའེ་པའེ་ཅང་སྐད།</translation>
    </message>
    <message>
        <source>Azeri</source>
        <translation>ཨ་སའེ་སྐད།</translation>
    </message>
    <message>
        <source>Bafia</source>
        <translation>པ་ཧྥེ་ཡ་སྐད།</translation>
    </message>
    <message>
        <source>Bafut</source>
        <translation>པ་ཧྥེ་ཐེ་སྐད།</translation>
    </message>
    <message>
        <source>Balinese</source>
        <translation>པ་ལི་སྐད།</translation>
    </message>
    <message>
        <source>Baluchi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bambara</source>
        <translation>པན་པ་ར་སྐད།</translation>
    </message>
    <message>
        <source>Bamun</source>
        <translation>པ་མུའུ་མུའུ་སྐད།</translation>
    </message>
    <message>
        <source>Bangla</source>
        <translation>བྷང་ག་ལའི་སྐད།</translation>
    </message>
    <message>
        <source>Basaa</source>
        <translation>པ་ས་སྐད།</translation>
    </message>
    <message>
        <source>Bashkir</source>
        <translation>པ་ཧྲི་ཅིར་སྐད།</translation>
    </message>
    <message>
        <source>Basque</source>
        <translation>པ་སི་ཁེ་སྐད།</translation>
    </message>
    <message>
        <source>Beja</source>
        <translation>པ་ཧྲ་སྐད།</translation>
    </message>
    <message>
        <source>Belarusian</source>
        <translation>ཨུ་རུ་སུ་དཀར་པོའི་སྐད།</translation>
    </message>
    <message>
        <source>Bemba</source>
        <translation>པེན་པ་སྐད།</translation>
    </message>
    <message>
        <source>Bena</source>
        <translation>པེ་ན་སྐད།</translation>
    </message>
    <message>
        <source>Bhojpuri</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bikol</source>
        <translation>པི་ཁོར་སྐད།</translation>
    </message>
    <message>
        <source>Bini</source>
        <translation>པི་ནི་སྐད།</translation>
    </message>
    <message>
        <source>Bislama</source>
        <translation>པི་སི་ལ་མ་སྐད།</translation>
    </message>
    <message>
        <source>Blin</source>
        <translation>པི་ལིན་སྐད།</translation>
    </message>
    <message>
        <source>Blissymbols</source>
        <translation>པུའུ་ལི་སི་མཚོན་རྟགས།</translation>
    </message>
    <message>
        <source>Bodo</source>
        <translation>པོ་ཏོ་སྐད།</translation>
    </message>
    <message>
        <source>Bosnian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Braj</source>
        <translation>པུའུ་ར་ཅེ་སྐད།</translation>
    </message>
    <message>
        <source>Breton</source>
        <translation>པུའུ་ལེ་ཐ་ཉི་སྐད།</translation>
    </message>
    <message>
        <source>Buginese</source>
        <translation>པུའུ་ཅི་སྐད།</translation>
    </message>
    <message>
        <source>Bulgarian</source>
        <translation>པའོ་ཅ་ལི་ཡ་སྐད།</translation>
    </message>
    <message>
        <source>Bulu</source>
        <translation>པུའུ་ལུའུ་སྐད།</translation>
    </message>
    <message>
        <source>Buriat</source>
        <translation>པུའུ་ལི་ཡ་ཐེ་སྐད།</translation>
    </message>
    <message>
        <source>Burmese</source>
        <translation>འབར་མའི་སྐད།</translation>
    </message>
    <message>
        <source>Caddo</source>
        <translation>ཁ་ཏོ་སྐད།</translation>
    </message>
    <message>
        <source>Cajun French</source>
        <translation>ཁ་ཀྲེན་ཧྥ་རན་སིའི་སྐད།</translation>
    </message>
    <message>
        <source>Cantonese</source>
        <translation>ཀོང་ཏུང་གི་སྐད།</translation>
    </message>
    <message>
        <source>Chinese, Cantonese</source>
        <translation>ཀོང་ཏུང་གི་སྐད།</translation>
    </message>
    <message>
        <source>Carib</source>
        <translation>ཅ་ལེ་པི་སྐད།</translation>
    </message>
    <message>
        <source>Carolina Algonquian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Catalan</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cayuga</source>
        <translation>ཁ་ཡིའུ་ཅའི་སྐད།</translation>
    </message>
    <message>
        <source>Cebuano</source>
        <translation>སེའུ་ཝུའུ་ཡི་སྐད།</translation>
    </message>
    <message>
        <source>Central Atlas Tamazight</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Central Kurdish</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kurdish, Sorani</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Central Ojibwa</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chadian Arabic</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chagatai</source>
        <translation>ཁྲ་ཧོ་ཐེ་སྐད།</translation>
    </message>
    <message>
        <source>Chakma</source>
        <translation>ཁྲ་ཁེ་མ་སྐད།</translation>
    </message>
    <message>
        <source>Chamorro</source>
        <translation>ཁྲ་མོ་ལུའོ་སྐད།</translation>
    </message>
    <message>
        <source>Chechen</source>
        <translation>ཁྲེ་ཁྲེན་སྐད།</translation>
    </message>
    <message>
        <source>Cherokee</source>
        <translation>ཆེ་ལུའོ་ཅི་སྐད།</translation>
    </message>
    <message>
        <source>Cheyenne</source>
        <translation>ཞ་ཡན་སྐད།</translation>
    </message>
    <message>
        <source>Chibcha</source>
        <translation>ཆི་པུའུ་ཁྲ་སྐད།</translation>
    </message>
    <message>
        <source>Chiga</source>
        <translation>ཆི་ཅ་སྐད།</translation>
    </message>
    <message>
        <source>Chilcotin</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chinese</source>
        <translation>རྒྱ་ཡིག</translation>
    </message>
    <message>
        <source>Simplified Chinese</source>
        <translation>ཟོར་ཡང་རྒྱ་ཡིག</translation>
    </message>
    <message>
        <source>Simplified Mandarin Chinese</source>
        <translation>དེང་རབས་ཀྱི་ཚད་ལྡན་རྒྱ་སྐད།（ཟོར་ཡང་།）</translation>
    </message>
    <message>
        <source>Traditional Chinese</source>
        <translation>ཟོར་་ལྕིའི་རྒྱ་ཡིག</translation>
    </message>
    <message>
        <source>Traditional Mandarin Chinese</source>
        <translation>དེང་རབས་ཀྱི་ཚད་ལྡན་རྒྱ་སྐད།（ཟོར་ལྕི།）</translation>
    </message>
    <message>
        <source>Chinese, Mandarin</source>
        <translation>སྤྱི་སྐད།</translation>
    </message>
    <message>
        <source>Chinook Jargon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chipewyan</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choctaw</source>
        <translation>ཆའོ་ཁོ་ཐུའོ་སྐད།</translation>
    </message>
    <message>
        <source>Church Slavic</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chuukese</source>
        <translation>ཁྲུའུ་ཁེ་སྐད།</translation>
    </message>
    <message>
        <source>Chuvash</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Classical Newari</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Classical Syriac</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Colognian</source>
        <translation>ཁོ་ལུང་སྐད།</translation>
    </message>
    <message>
        <source>Comorian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Coptic</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cornish</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Corsican</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cree</source>
        <translation>ཁེ་ལིའི་སྐད།</translation>
    </message>
    <message>
        <source>Crimean Tatar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Croatian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Czech</source>
        <translation>ཅེ་ཁེའི་སྐད།</translation>
    </message>
    <message>
        <source>Dakota</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Danish</source>
        <translation>ཏེན་མག་གི་སྐད།</translation>
    </message>
    <message>
        <source>Dargwa</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dazaga</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delaware</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dinka</source>
        <translation>ཏིན་ཁའི་སྐད།</translation>
    </message>
    <message>
        <source>Divehi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dogri</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dogrib</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Duala</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dutch</source>
        <translation>ཧོ་ལན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Flemish</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dyula</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dzongkha</source>
        <translation>རྫོང་ཁའི་སྐད།</translation>
    </message>
    <message>
        <source>Eastern Frisian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Efik</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ekajuk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Elamite</source>
        <translation>ཨའེ་ལན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Embu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>English</source>
        <translation>དབྱིན་སྐད།</translation>
    </message>
    <message>
        <source>Australian English</source>
        <translation>ཨོ་སི་ཁྲུ་ལི་ཡའི་དབྱིན་སྐད།</translation>
    </message>
    <message>
        <source>Canadian English</source>
        <translation>ཁ་ན་ཏའི་དབྱིན་སྐད།</translation>
    </message>
    <message>
        <source>British English</source>
        <translation>དབྱིན་ཇིའི་སྐད།</translation>
    </message>
    <message>
        <source>UK English</source>
        <translation>དབྱིན་ཇིའི་སྐད།</translation>
    </message>
    <message>
        <source>American English</source>
        <translation>ཨ་རིའི་དབྱིན་སྐད།</translation>
    </message>
    <message>
        <source>US English</source>
        <translation>ཨ་རིའི་དབྱིན་སྐད།</translation>
    </message>
    <message>
        <source>Erzya</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Esperanto</source>
        <translation>འཛམ་གླིང་སྐད།</translation>
    </message>
    <message>
        <source>Estonian</source>
        <translation>ཨེ་སོ་ནི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <source>Ewe</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ewondo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fang</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fanti</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Faroese</source>
        <translation>ཧྥ་ལུའོ་ཡི་སྐད།</translation>
    </message>
    <message>
        <source>Fijian</source>
        <translation>ཧྥི་ཅིའི་སྐད།</translation>
    </message>
    <message>
        <source>Filipino</source>
        <translation>ཧྥི་ལི་ཕིན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Finnish</source>
        <translation>ཧྥིན་ལན་སྐད།</translation>
    </message>
    <message>
        <source>Fon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>French</source>
        <translation>ཧྥ་རན་སེའི་སྐད།</translation>
    </message>
    <message>
        <source>Canadian French</source>
        <translation>ཁ་ན་ཏའི་ཧྥ་རན་སེའི་སྐད།</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>སུའེ་ཙེར་གྱི་ཧྥ་རན་སེའི་སྐད།</translation>
    </message>
    <message>
        <source>Friulian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fula</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ga</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gagauz</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Galician</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gan Chinese</source>
        <translation>ཅང་ཞིའི་སྐད།</translation>
    </message>
    <message>
        <source>Ganda</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gayo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gbaya</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Geez</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Georgian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>German</source>
        <translation>འཇར་མན་སྐད།</translation>
    </message>
    <message>
        <source>Austrian German</source>
        <translation>ཨོ་སི་ཁྲུ་རི་ཡའི་འཇར་མན་སྐད།</translation>
    </message>
    <message>
        <source>Swiss High German</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ghomala</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gilbertese</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gondi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gorontalo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gothic</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Grebo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Greek</source>
        <translation>གྷི་རིག་གི་སྐད།</translation>
    </message>
    <message>
        <source>Guarani</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gujarati</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gusii</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gwichʼin</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Haida</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Haitian Creole</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hakka Chinese</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Halkomelem</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Haryanvi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hausa</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hawaiian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hebrew</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Herero</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hiligaynon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hindi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hinglish</source>
        <translation>རྒྱ་གར་གྱི་དབྱིན་སྐད།</translation>
    </message>
    <message>
        <source>Hiri Motu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hittite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hmong</source>
        <translation>མིའོ་རིགས་ཀྱི་སྐད།</translation>
    </message>
    <message>
        <source>Hungarian</source>
        <translation>ཧང་ག་རིའི་སྐད།</translation>
    </message>
    <message>
        <source>Hupa</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Iban</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ibibio</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icelandic</source>
        <translation>འཁྱགས་གླིང་གི་སྐད།</translation>
    </message>
    <message>
        <source>Ido</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Igbo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Iloko</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Inari Sami</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Indonesian</source>
        <translation>ཧིན་རྡུ་ཉི་ཞི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <source>Ingush</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Innu-aimun</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Interlingua</source>
        <translation>རྒྱལ་སྤྱིའི་སྐད།</translation>
    </message>
    <message>
        <source>Interlingue</source>
        <translation>རྒྱལ་སྤྱིའི་ཡི་གེ།（E）</translation>
    </message>
    <message>
        <source>Inuktitut</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Inupiaq</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Irish</source>
        <translation>ཨིར་ལན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Italian</source>
        <translation>དབྱི་ཐ་ལིའི་སྐད།</translation>
    </message>
    <message>
        <source>Japanese</source>
        <translation>ལྗར་པན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Javanese</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Jju</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Jola-Fonyi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Judeo-Arabic</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Judeo-Persian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kabardian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kabuverdianu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kabyle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kachin</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kaingang</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kako</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kalaallisut</source>
        <translation>ཀེ་རུན་ལན་སྐད།</translation>
    </message>
    <message>
        <source>Kalenjin</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kalmyk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kamba</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kanembu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kannada</source>
        <translation>ཁ་ན་ཏ་སྐད།</translation>
    </message>
    <message>
        <source>Kanuri</source>
        <translation>ཁ་ནུའུ་ལི་སྐད།</translation>
    </message>
    <message>
        <source>Kara-Kalpak</source>
        <translation>ཁ་ལ་ཁེར་ཕ་ཁོ་སྐད།</translation>
    </message>
    <message>
        <source>Karachay-Balkar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Karelian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kashmiri</source>
        <translation>ཁ་ཆེའི་སྐད།</translation>
    </message>
    <message>
        <source>Kashubian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kawi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kazakh</source>
        <translation>ཧ་སག་སྐད།</translation>
    </message>
    <message>
        <source>Khasi</source>
        <translation>ཁ་ཞིའི་སྐད།</translation>
    </message>
    <message>
        <source>Khmer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Khotanese</source>
        <translation>ཁོ་ཐན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Kikuyu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kimbundu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kinyarwanda</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Klingon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kom</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Komi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Komi-Permyak</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kongo</source>
        <translation>ཁོང་ཀོའི་སྐད།</translation>
    </message>
    <message>
        <source>Konkani</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Korean</source>
        <translation>ཁོ་རེ་ཡའི་སྐད།</translation>
    </message>
    <message>
        <source>Koro</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kosraean</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Koyra Chiini</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Koyraboro Senni</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kpelle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kuanyama</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kumyk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kurdish</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kurukh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kutenai</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kwakʼwala</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kwasio</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kyrgyz</source>
        <translation>ཁོར་ཁེ་ཙིའི་སྐད།</translation>
    </message>
    <message>
        <source>Kʼicheʼ</source>
        <translation>ཅི་ཆེ་སྐད།</translation>
    </message>
    <message>
        <source>Ladino</source>
        <translation>ལ་ཏི་ནོར་སྐད།</translation>
    </message>
    <message>
        <source>Lakota</source>
        <translation>ལ་ཁོ་ཐ་སྐད།</translation>
    </message>
    <message>
        <source>Lamba</source>
        <translation>ལན་པ་སྐད།</translation>
    </message>
    <message>
        <source>Langi</source>
        <translation>ལང་ཅི་སྐད།</translation>
    </message>
    <message>
        <source>Lao</source>
        <translation>ལོ་སིའི་སྐད།</translation>
    </message>
    <message>
        <source>Latin</source>
        <translation>ལ་ཏིང་གི་སྐད།</translation>
    </message>
    <message>
        <source>Latvian</source>
        <translation>ལ་ཐོ་ཝེ་ཡ་སྐད།</translation>
    </message>
    <message>
        <source>Lezghian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ligurian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lillooet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Limburgish</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lingala</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lithuanian</source>
        <translation>ལི་ཐུ་ཝན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Lojban</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Louisiana Creole</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Low German</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Low Saxon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lower Sorbian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lozi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Luba-Katanga</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Luba-Lulua</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Luiseno</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lule Sami</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lunda</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Luo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Luxembourgish</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Luyia</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Maba</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Macedonian</source>
        <translation>མ་ཆི་ཏུན་སྐད།</translation>
    </message>
    <message>
        <source>Machame</source>
        <translation>མ་ཆེ་མུའུ་སྐད།</translation>
    </message>
    <message>
        <source>Madurese</source>
        <translation>མ་ཏུའུ་ལ་སྐད།</translation>
    </message>
    <message>
        <source>Mafa</source>
        <translation>མ་ཧྥ་སྐད།</translation>
    </message>
    <message>
        <source>Magahi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Maithili</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Makasar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Makhuwa Meetto</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Makonde</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Malagasy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Malay</source>
        <translation>མ་ལེའི་སྐད།</translation>
    </message>
    <message>
        <source>Malayalam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Maliseet-Passamaquoddy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Maltese</source>
        <translation>མར་ཐའི་སྐད།</translation>
    </message>
    <message>
        <source>Manchu</source>
        <translation>མན་ཇུའི་སྐད།</translation>
    </message>
    <message>
        <source>Mandar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mandingo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Manipuri</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Manx</source>
        <translation>མེན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Māori</source>
        <translation>མའོ་ལིའི་སྐད།</translation>
    </message>
    <message>
        <source>Mapuche</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Marathi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mari</source>
        <translation>མ་རིའི་སྐད།</translation>
    </message>
    <message>
        <source>Marshallese</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Marwari</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Masai</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mazanderani</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Medumba</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mende</source>
        <translation>མེན་ཏེའི་སྐད།</translation>
    </message>
    <message>
        <source>Meru</source>
        <translation>མེ་ལུའུ་ཡི་སྐད།</translation>
    </message>
    <message>
        <source>Metaʼ</source>
        <translation>མེ་ཐའི་སྐད།</translation>
    </message>
    <message>
        <source>Mi&apos;kmaq</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Michif</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Middle Dutch</source>
        <translation>གནའ་བོའི་ཧོ་ལན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Middle English</source>
        <translation>གནའ་བོའི་དབྱིན་སྐད།</translation>
    </message>
    <message>
        <source>Middle French</source>
        <translation>གནའ་བོའི་ཧྥ་རན་སེའི་སྐད།</translation>
    </message>
    <message>
        <source>Middle High German</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Middle Irish</source>
        <translation>གནའ་བོའི་ཨིར་ལན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Min Nan Chinese</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Minangkabau</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mirandese</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mizo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mohawk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Moksha</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mongo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mongolian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Moose Cree</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Morisyen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mossi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Multiple languages</source>
        <translation>སྐད་རིགས་སྣ་མང་།</translation>
    </message>
    <message>
        <source>Mundang</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Muscogee</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Myene</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>N’Ko</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Najdi Arabic</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Arabic, Najdi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nama</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nauru</source>
        <translation>ནོ་རུའི་སྐད།</translation>
    </message>
    <message>
        <source>Navajo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ndonga</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Neapolitan</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nepali</source>
        <translation>བལ་པོའི་སྐད།</translation>
    </message>
    <message>
        <source>Newari</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ngambay</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ngiemboon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ngomba</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nheengatu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nias</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nigerian Pidgin</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Niuean</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No linguistic content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nogai</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>North Ndebele</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Northern East Cree</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Northern Frisian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Northern Luri</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Northern Sami</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Northern Sotho</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Northern Tutchone</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Northwestern Ojibwa</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Norwegian</source>
        <translation>ནོར་ཝེའི་སྐད།</translation>
    </message>
    <message>
        <source>Norwegian Bokmål</source>
        <translation>ནོར་ཝེའི་ཡིག་སྐད།</translation>
    </message>
    <message>
        <source>Norwegian Nynorsk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nuer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nyamwezi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nyanja</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nyankole</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nyasa Tonga</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nyoro</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nzima</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Obolo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Occitan</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Odia</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Oji-Cree</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ojibwa</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Okanagan</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Old English</source>
        <translation>གནའ་བོའི་དབྱིན་སྐད།</translation>
    </message>
    <message>
        <source>Old French</source>
        <translation>གནའ་བོའི་ཧྥ་རན་སེའི་སྐད།</translation>
    </message>
    <message>
        <source>Old High German</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Old Irish</source>
        <translation>གནའ་བོའི་ཨིར་ལན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Old Norse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Old Persian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Old Provençal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Oromo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Osage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ossetic</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ottoman Turkish</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pahlavi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Palauan</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pali</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pampanga</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pangasinan</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Papiamento</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pashto</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Persian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dari</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Phoenician</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pijin</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Plains Cree</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pohnpeian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Polish</source>
        <translation>ཕོ་ལན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Portuguese</source>
        <translation>ཕོར་ཐིའུ་ཀལ་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Brazilian Portuguese</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>European Portuguese</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prussian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Punjabi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Quechua</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rajasthani</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rapanui</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rarotongan</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rohingya</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Romanian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Moldavian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Romansh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Romany</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rombo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rundi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Russian</source>
        <translation>ཨུ་རུ་སུའི་སྐད།</translation>
    </message>
    <message>
        <source>Rwa</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saamia</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saho</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Samaritan Aramaic</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Samburu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Samoan</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sandawe</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sango</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sangu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sanskrit</source>
        <translation>ལེགས་སྦྱར་སྐད།</translation>
    </message>
    <message>
        <source>Santali</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sardinian</source>
        <translation>ས་ཏིང་གི་སྐད།</translation>
    </message>
    <message>
        <source>Sasak</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scots</source>
        <translation>སུའུ་ཀེ་ལན་སྐད།</translation>
    </message>
    <message>
        <source>Scottish Gaelic</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Selkup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sena</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Seneca</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Serbian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Serbo-Croatian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Serer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Seselwa Creole French</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shambala</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shan</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shona</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sichuan Yi</source>
        <translation>སི་ཁྲོན་དབྱིས་རིགས་སྐད།</translation>
    </message>
    <message>
        <source>Sicilian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sidamo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Siksiká</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sindhi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sinhala</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skolt Sami</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slave</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slovak</source>
        <translation>སི་ལོ་ཝ་ཁེའི་སྐད།</translation>
    </message>
    <message>
        <source>Slovenian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Soga</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sogdien</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Somali</source>
        <translation>སོ་མ་ལིའི་སྐད།</translation>
    </message>
    <message>
        <source>Soninke</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>South Ndebele</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Southern Altai</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Southern East Cree</source>
        <translation>ཤར་ལྷོའི་རྒྱུད་ཁེ་ལི་ཡི་སྐད།</translation>
    </message>
    <message>
        <source>Southern Haida</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Southern Kurdish</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Southern Lushootseed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Southern Sami</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Southern Sotho</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Southern Tutchone</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Spanish</source>
        <translation>སི་ཕེན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Latin American Spanish</source>
        <translation>ལ་ཏིང་མེ་གླིང་གི་སི་ཕེན་སྐད།</translation>
    </message>
    <message>
        <source>European Spanish</source>
        <translation>ཡོ་རོབ་ཀྱི་སི་ཕེན་སྐད།</translation>
    </message>
    <message>
        <source>Mexican Spanish</source>
        <translation>མོ་ཞི་ཁོའི་སི་ཕན་སྐད།</translation>
    </message>
    <message>
        <source>Sranan Tongo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Standard Moroccan Tamazight</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Straits Salish</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sukuma</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sumerian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sundanese</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Susu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Swahili</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Congo Swahili</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Swampy Cree</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Swati</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Swedish</source>
        <translation>སུའེ་ཏེན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Swiss German</source>
        <translation>སུའེ་ཏེན་གྱི་འཇར་མན་སྐད།</translation>
    </message>
    <message>
        <source>Syriac</source>
        <translation>སི་རི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <source>Tachelhit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tagalog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tagish</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tahitian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tahltan</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Taita</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tajik</source>
        <translation>ཐ་ཅི་ཁེའི་སྐད།</translation>
    </message>
    <message>
        <source>Tamashek</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tamil</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Taroko</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tasawaq</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tatar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Telugu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tereno</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Teso</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tetum</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Thai</source>
        <translation>ཐེ་ལན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Tibetan</source>
        <translation>བོད་སྐད།</translation>
    </message>
    <message>
        <source>Tigre</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tigrinya</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Timne</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tiv</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tlingit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tok Pisin</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tokelau</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Toki Pona</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tongan</source>
        <translation>ཐང་ཀའི་སྐད།</translation>
    </message>
    <message>
        <source>Tsimshian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tsonga</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tswana</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tumbuka</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turkish</source>
        <translation>ཐུར་ཁེའི་སྐད།</translation>
    </message>
    <message>
        <source>Turkmen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tuvalu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tuvinian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Twi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tyap</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Udmurt</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ugaritic</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ukrainian</source>
        <translation>ཡུག་རེན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Umbundu</source>
        <translation>ཝུང་པེན་ཏུའུ་ཡི་སྐད།</translation>
    </message>
    <message>
        <source>Unknown language</source>
        <translation>མ་ཤེས་པའི་སྐད།</translation>
    </message>
    <message>
        <source>Upper Sorbian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Urdu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Uyghur</source>
        <translation>ཡུ་གུར་སྐད།</translation>
    </message>
    <message>
        <source>Uzbek</source>
        <translation>ཝུའུ་ཙི་པིའེ་ཁེའི་སྐད།</translation>
    </message>
    <message>
        <source>Vai</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Venda</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Venetian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Veps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Vietnamese</source>
        <translation>ཝེ་ཐེ་ནམ་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Volapük</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Votic</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Vunjo</source>
        <translation>ཝུན་ཅིའུ་ཡི་སྐད།</translation>
    </message>
    <message>
        <source>Walloon</source>
        <translation>ཝ་ལུང་གི་སྐད།</translation>
    </message>
    <message>
        <source>Walser</source>
        <translation>ཝར་སེའི་སྐད།</translation>
    </message>
    <message>
        <source>Waray</source>
        <translation>ཝ་རུའེ་ཡི་སྐད།</translation>
    </message>
    <message>
        <source>Warlpiri</source>
        <translation>ཝར་ཕི་རུའེ་ཡི་སྐད།</translation>
    </message>
    <message>
        <source>Washo</source>
        <translation>ཝ་ཧྲའོ་ཡི་སྐད།</translation>
    </message>
    <message>
        <source>Welsh</source>
        <translation>ཝེར་ཧྲིའི་སྐད།</translation>
    </message>
    <message>
        <source>Western Balochi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Western Canadian Inuktitut</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Western Frisian</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Western Ojibwa</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Western Panjabi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wolaytta</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wolof</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wu Chinese</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Xhosa</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Xiang Chinese</source>
        <translation>ཧུའུ་ནན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Yakut</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Yangben</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Yao</source>
        <translation>ཡའོ་རིགས་ཀྱི་སྐད།</translation>
    </message>
    <message>
        <source>Yapese</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Yemba</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Yiddish</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Yoruba</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Zapotec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Zarma</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Zaza</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Zenaga</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Zhuang</source>
        <translation>ཀྲོང་རིགས་ཀྱི་སྐད།</translation>
    </message>
    <message>
        <source>Zulu</source>
        <translation>ཙུའུ་ལུའུ་ཡི་སྐད།</translation>
    </message>
    <message>
        <source>Zuni</source>
        <translation>ཙུའུ་ནིའི་སྐད།</translation>
    </message>
    <message>
        <source>Bengali</source>
        <translation>བྷང་ག་ལའི་སྐད།</translation>
    </message>
    <message>
        <source>Central Morocco Tamazight</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chickasaw</source>
        <translation>ཆི་ཁི་སོའོ་ཡི་སྐད།</translation>
    </message>
    <message>
        <source>Church</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fulah</source>
        <translation>ཧྥུ་ལའི་སྐད།</translation>
    </message>
    <message>
        <source>Gaelic</source>
        <translation>ཀེར་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Greenlandic</source>
        <translation>ཀེ་རུན་ལན་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Jola Fonyi</source>
        <translation>ཆའོ་ལ་ཧྥུ་ནིའི་སྐད།</translation>
    </message>
    <message>
        <source>Kenyang</source>
        <translation>ཅི་ཡ་མུའི་སྐད།</translation>
    </message>
    <message>
        <source>Kiche</source>
        <translation>ཅི་ཆེའི་སྐད།</translation>
    </message>
    <message>
        <source>Kirghiz</source>
        <translation>ཅིར་ཅི་སིའི་སྐད།</translation>
    </message>
    <message>
        <source>Luba Katanga</source>
        <translation>ལུའུ་པ་ཁ་ཐ་ཕའེ་ཡི་སྐད།</translation>
    </message>
    <message>
        <source>Makhuwa</source>
        <translation>མེ་ཐའི་ཡི་སྐད།</translation>
    </message>
    <message>
        <source>Meetto</source>
        <translation>ན་ཝ་ཧོའི་སྐད།</translation>
    </message>
    <message>
        <source>Maori</source>
        <translation>ཨེན་ཁོའི་སྐད།</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>ནོར་ཝེ་པོ་ཁོ་མར་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Navaho</source>
        <translation>ཨའོ་ལི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <source>Nko</source>
        <translation>ས་ཧའི་སྐད།</translation>
    </message>
    <message>
        <source>Norwegian Bokmal</source>
        <translation>ཞི་ལའེ་ཞི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <source>Tai Dam</source>
        <translation>ཐའེ་ཏན་སྐད།</translation>
    </message>
    <message>
        <source>Uighur</source>
        <translation>ཡུ་གུར་གྱི་སྐད།</translation>
    </message>
    <message>
        <source>Volapuk</source>
        <translation>འཛམ་གླིང་སྐད།</translation>
    </message>
    <message>
        <source>Oriya</source>
        <translation>ཨའོ་ལི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <source>Sakha</source>
        <translation>ས་ཧའི་སྐད།</translation>
    </message>
    <message>
        <source>Silesian</source>
        <translation>ཞི་ལའེ་ཞི་ཡའི་སྐད།</translation>
    </message>
    <message>
      <source>Walamo</source>
      <translation>ཝ་ལ་མོའི་སྐད།</translation>
      </message>
</context>
</TS>